@@ -16,7 +16,7 @@
 from ctypes import *
 import win32api, win32con
 from .base import PyMouseMeta, PyMouseEventMeta, ScrollSupportError
-import pythoncom, pyHook
+import pythoncom
 from time import sleep
 
 class POINT(Structure):
@@ -83,14 +83,14 @@ in Windows. This feature is only available on Mac.')
         return width, height
 
 class PyMouseEvent(PyMouseEventMeta):
-    def __init__(self, capture, capture_move):
+    def __init__(self, capture=False, capture_move=False):
+        import pyHook
+
         PyMouseEventMeta.__init__(self, capture=capture, capture_move=capture_move)
         self.hm = pyHook.HookManager()
 
     def run(self):
-        self.hm.MouseAllButtons = self._click
-        self.hm.MouseMove = self._move
-        #I think I can add scrollwheel support at some point
+        self.hm.MouseAll = self._action
         self.hm.HookMouse()
         while self.state:
             sleep(0.01)
@@ -100,10 +100,14 @@ class PyMouseEvent(PyMouseEventMeta):
         self.hm.UnhookMouse()
         self.state = False
 
-    def _click(self, event):
+    def _action(self, event):
+        import pyHook
         x, y = event.Position
 
-        if event.Message == pyHook.HookConstants.WM_LBUTTONDOWN:
+        if event.Message == pyHook.HookConstants.WM_MOUSEMOVE:
+            self.move(x,y)
+
+        elif event.Message == pyHook.HookConstants.WM_LBUTTONDOWN:
             self.click(x, y, 1, True)
         elif event.Message == pyHook.HookConstants.WM_LBUTTONUP:
             self.click(x, y, 1, False)
@@ -115,9 +119,9 @@ class PyMouseEvent(PyMouseEventMeta):
             self.click(x, y, 3, True)
         elif event.Message == pyHook.HookConstants.WM_MBUTTONUP:
             self.click(x, y, 3, False)
+            
+        elif event.Message == pyHook.HookConstants.WM_MOUSEWHEEL:
+            # event.Wheel is -1 when scrolling down, 1 when scrolling up
+            self.scroll(x,y,event.Wheel)
+        
         return not self.capture
-
-    def _move(self, event):
-        x, y = event.Position
-        self.move(x, y)
-        return not self.capture_move
